@@ -6,6 +6,7 @@ from __future__ import unicode_literals
 import unicodedata
 from natsort.compat.py23 import py23_range, py23_unichr
 from natsort.unicode_numbers import (
+    numeric_hex,
     numeric_chars,
     numeric,
     digit_chars,
@@ -24,7 +25,9 @@ def test_digit_chars_contains_only_valid_unicode_digit_characters():
 
 
 def test_numeric_chars_contains_all_valid_unicode_numeric_characters():
-    for i in py23_range(0X10FFFF):
+    set_numeric_hex = set(numeric_hex)
+    set_numeric_chars = set(numeric_chars)
+    for i in py23_range(0X110000):
         try:
             a = py23_unichr(i)
         except ValueError:
@@ -32,11 +35,14 @@ def test_numeric_chars_contains_all_valid_unicode_numeric_characters():
         if a in set('0123456789'):
             continue
         if unicodedata.numeric(a, None) is not None:
-            assert a in numeric_chars
+            assert i in set_numeric_hex
+            assert a in set_numeric_chars
 
 
 def test_digit_chars_contains_all_valid_unicode_digit_characters():
-    for i in py23_range(0X10FFFF):
+    set_numeric_hex = set(numeric_hex)
+    set_numeric_chars = set(numeric_chars)
+    for i in py23_range(0X110000):
         try:
             a = py23_unichr(i)
         except ValueError:
@@ -44,7 +50,8 @@ def test_digit_chars_contains_all_valid_unicode_digit_characters():
         if a in set('0123456789'):
             continue
         if unicodedata.digit(a, None) is not None:
-            assert a in digit_chars
+            assert i in set_numeric_hex
+            assert a in set_numeric_chars
 
 
 def test_combined_string_contains_all_characters_in_list():
